@@ -2,7 +2,9 @@ package main;
 
 use strict;
 use warnings;
+use utf8;
 
+use Encode;
 use SOAP::Lite;
 use SOAP::Transport::HTTP;
 
@@ -15,9 +17,7 @@ $soap->handle();
 sub test {
     my ($self, $envelope) = @_;
 
-use Encode;
-#    return SOAP::Data->name('testResult')->value('Überall')->type('string');
-    return SOAP::Data->name('testResult')->value(Encode::encode_utf('Überall'))->type('string');
+    return SOAP::Data->name('testResult')->value(Encode::encode_utf8('Überall'))->type('string');
 }
 
 1;
\ No newline at end of file
